@@ -19,6 +19,8 @@ def wait_until(somepredicate, timeout, period=1, *args, **kwargs):
 def data_factory(data_format="list", **options):
     def get_df(columns, data):
         data_list = get_list(columns, data)
+        # enforce to show the data frame dimesion e.g: [499 rows x 9 columns]
+        pd.set_option("show_dimensions", True)
         return pd.DataFrame(data_list[1:], columns=data_list[0])
 
     def get_np(columns, data):
